@@ -53,6 +53,7 @@
 #![deny(missing_docs)]
 #![warn(noop_method_call)]
 #![deny(unreachable_pub)]
+#![deny(clippy::all)]
 #![deny(clippy::await_holding_lock)]
 #![deny(clippy::cargo_common_metadata)]
 #![deny(clippy::cast_lossless)]
@@ -74,6 +75,7 @@
 #![warn(clippy::option_option)]
 #![warn(clippy::rc_buffer)]
 #![deny(clippy::ref_option_ref)]
+#![warn(clippy::semicolon_if_nothing_returned)]
 #![warn(clippy::trait_duplication_in_bounds)]
 #![deny(clippy::unnecessary_wraps)]
 #![warn(clippy::unseparated_literal_suffix)]
@@ -535,7 +537,9 @@ pub struct UncheckedCert {
 
     /// The signed text of the certificate. (Checking ed25519 signatures
     /// forces us to store this.
-    text: Vec<u8>, // XXXX It would be better to store a hash here.
+    // TODO(nickm)  It would be better to store a hash here, but we
+    // don't have the right Ed25519 API.
+    text: Vec<u8>,
 
     /// The alleged signature
     signature: ed25519::Signature,
